import * as React from 'react';
import { OFRest } from '../../components/Rest';
import * as Utils from '../../components/Utils';
import Checkbox from 'material-ui/Checkbox';
import RaisedButton from 'material-ui/RaisedButton';
import { TargetCreator } from '../../components/TargetCreate';

const styles = {

  checkbox: {
    marginBottom: 16,
  },
};


export class DiscoveryResult extends React.Component<any, any> {
  list: any;

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
      result: [],
    };
  }

  componentWillMount() {
    let data = '{"startDate":1496812121000,"endDate":1496812155000,"result":true,"zone":{"ip":3232235985,"mask":24,"iface":"enp0s3","mac":8796753988883,"firstScanRange":3232235777,"lastScanRange":3232236030,"hosts":[{"firstScanRange":1,"lastScanRange":10000,"name":"","ip":3232235985,"mac":8796753988883,"ports":null,"createDate":1496812124000,"updateDate":1496812124000},{"firstScanRange":1,"lastScanRange":10000,"name":"","ip":3232235881,"mac":23084201235582,"ports":[{"createDate":-62135596800000,"updateDate":-62135596800000,"services":[{"createDate":-62135596800000,"updateDate":-62135596800000,"portType":"TCP","serviceName":"SMTP"}],"portType":"TCP","portNumber":25},{"createDate":-62135596800000,"updateDate":-62135596800000,"services":[{"createDate":-62135596800000,"updateDate":-62135596800000,"portType":"TCP","serviceName":"HTTP"}],"portType":"TCP","portNumber":3000},{"createDate":-62135596800000,"updateDate":-62135596800000,"services":[{"createDate":-62135596800000,"updateDate":-62135596800000,"portType":"TCP","serviceName":"HTTP"}],"portType":"TCP","portNumber":80}],"createDate":1496812124000,"updateDate":1496812124000}]}}';
    let obj = JSON.parse(data);
    this.list = Array();
    this.setState({
      result: obj,
    });
  }

  getData() {
    let obj: any;
    obj = {
      "id": "0",
      "member": {
        "id": "1"
      }
    };

    let os: OFRest = new OFRest("Target", "List", obj);
    var that: any = this;
    os.Call().then(function (res) {
      return res.json();
    }).then(function (json) {
      let targetList = JSON.parse(json.resultStr);
      that.setState({
        targets: targetList,
      });
    }).catch(function (err) {
      console.log(err);
    });
  }

  handleNext = () => {
    for (var i = 0; i < this.list.length; i++) {
      var target = this.list[i];
      console.log(target);
    }

    let os: OFRest = new OFRest("Target", "CreateAll", this.list);

    os.Call().then(function (res) {
      return res.json();
    }).then(function (res) {
      console.log(res);
    }).catch(function (err) {
      console.log(err);
    });

  }

  handleTargetCheck = (seq: number, type: string, checked: boolean, host: any, port: any) => {
    let obj: any;
    if (type === "host") {
      obj = {
        "seq": seq,
        "ip": host.ip,
        "port": 0,
        "portType": "",
        "vendorName": host.name,
      };
    } else {
      obj = {
        "seq": seq,
        "ip": host.ip,
        "port": port.portNumber,
        "portType": port.portType,
        "vendorName": port.services[0].serviceName,
      };
    }

    if (checked) {
      this.list.push(obj);
    } else {
      for (var i = 0; i < this.list.length; i++) {
        if (this.list[i].seq === seq) {
          this.list.splice(i, 1);
        }
      }
    }
    console.log(this.list);
  }


  renderHosts = (zone: any, num: number) => {
    if (zone.hosts === null || zone.hosts.length === 0) {
      return null;
    }
    return <div style={{ marginLeft: 20 }}>
      {zone.hosts.map((host: any, index: number) => (
        <div key={index}>
          <Row type='host' seq={num++} host={host} name={Utils.int2ip(host.ip)} desc={host.mac} onCheck={this.handleTargetCheck.bind(this)} />
          {this.renderPorts(host, num)}
        </div>
      ))}
    </div>;
  }

  renderPorts = (host: any, num: number) => {
    if (host.ports === null || host.ports.length === 0) {
      return null;
    }
    return <div style={{ marginLeft: 20 }}>
      {host.ports.map((port: any, index: number) => (
        <div key={index}>
          <Row type='service' seq={num++} host={host} port={port} name={port.portType + port.portNumber} desc={port.services[0].serviceName} onCheck={this.handleTargetCheck.bind(this)} />
        </div>
      ))}
    </div>;
  }

  render() {
    var num = 0;
    return (
      <div style={{ margin: 20 }}>
        <div>
          Elapsed : {Utils.sec2date(this.state.result.startDate)} ~ {Utils.sec2date(this.state.result.endDate)}
        </div>

        <div>
          Scan Range : {Utils.int2ip(this.state.result.zone.firstScanRange)} ~ {Utils.int2ip(this.state.result.zone.lastScanRange)}
        </div>

        <div>
          Iface : {this.state.result.zone.iface}
        </div>
        <div>
          IP : {Utils.int2ip(this.state.result.zone.ip)}/{this.state.result.zone.mask}
        </div>
        <div>
          MacAddress : {Utils.intToMac(this.state.result.zone.mac)}
        </div>

        <div style={{ margin: 20 }} > Targets </div>
        {this.renderHosts(this.state.result.zone, num)}

        <RaisedButton label="Next" primary={true} onClick={this.handleNext.bind(this)} style={{ margin: 20 }} />
      </div>
    );
  }
}

export class Row extends React.Component<any, any> {
  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
    };
  }

  handleCheck(ev: any, checked: boolean) {
    this.props.onCheck(this.props.seq, this.props.type, checked, this.props.host, this.props.port);
  }

  render() {
    return (
      <Checkbox label={this.props.name + "-------------" + this.props.desc} style={styles.checkbox} onCheck={this.handleCheck.bind(this)} />
    );
  }
}