import * as React from 'react';
import { Container, Menu, Sidebar, Segment, Icon, Breadcrumb } from 'semantic-ui-react';
import { Header } from './Header';
import { Footer } from './Footer';

import { Routes } from '../../../Routes';
import { Router } from 'react-router';
import * as History from 'history';

const history = History.createHashHistory();

export class Layout extends React.Component<any, any> {

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
      notification_visible:false,
    };
  }

  onSidebar = () => {
    this.setState({notification_visible:!this.state.notification_visible})
  }

  render() {
    return (
      <div>
        <Header onSidebar={this.onSidebar.bind(this)}/>
        <Sidebar.Pushable as={Segment} vertical >
          <Sidebar
            as={Menu}
            animation='overlay'
            width='thin'
            direction='right'
            visible={this.state.notification_visible}
            icon='labeled'
            vertical
            inverted
          >
            <Menu.Item name='home'>
              <Icon name='home' />
              Home
            </Menu.Item>
            <Menu.Item name='gamepad'>
              <Icon name='gamepad' />
              Games
            </Menu.Item>
            <Menu.Item name='camera'>
              <Icon name='camera' />
              Channels
            </Menu.Item>
          </Sidebar>

          <Sidebar.Pusher >
            <Breadcrumb style={{ padding: '5px 20px 0px' }} size='mini'>
              <Breadcrumb.Section link>Home</Breadcrumb.Section>
              <Breadcrumb.Divider icon='right angle' />
              <Breadcrumb.Section link>Monitoring</Breadcrumb.Section>
              <Breadcrumb.Divider icon='right angle' />
              <Breadcrumb.Section active>Probe</Breadcrumb.Section>
            </Breadcrumb>

            <Segment vertical>
              <Container>
                <Router history={history} >
                  <Routes />
                </Router>
              </Container>

              <Footer />
            </Segment>
          </Sidebar.Pusher>
        </Sidebar.Pushable>


      </div>
    );
  }
}



